@@ -1,5 +1,5 @@
-rxPermissive({
-
+rxodeTest(
+  {
     context("Test large model compiles")
 
     mod <- RxODE("
@@ -1525,7 +1525,8 @@ d/dt(RISF) = tubular_reabsorption - capillary_filtration;
 ")
 
     test_that("large models compile", {
-        expect_true(inherits(mod, "RxODE"))
+      expect_true(inherits(mod, "RxODE"))
     })
-
-}, cran=FALSE)
+  },
+  test = "lvl2"
+)
